==> cobs-0.8.tgz: cobs-0.8/new/sb.php <==
<meta http-equiv="Content-Type" CONTENT="text/html; charset=big5">
<?php
require("config.php");
require("dbconfig.php");
require("subref.php");
$MD[0]="<font size=\"2\">";
/*****************************************
$RD=0 only gy
$RD=1 gy and Ūg
$RD=2 only Ūg
*****************************************/
/**** bible.fhl.net ******/
$MD[1]="<BODY bgcolor=\"#0000c0\" TEXT=\"#eeeeee\" LINK=\"#ffff44\" VLINK=\"#ffff44\" ALINK=\"#ffff44\" ><font size=\"2\">";
/****** a2z.fhl.net *******/
$MD[2]="<BODY bgcolor=\"#aa0000\" TEXT=\"#ffff44\" LINK=\"#eeeeee\" VLINK=\"#eeeeee\" ALINK=\"#eeeeee\" ><font size=\"1\">";
/****** http://www.biblesociety-tw.org/ *******/
$MD[3]="<BODY bgcolor=\"#808040\" TEXT=\"#ffffff\" LINK=\"#eeeeee\" VLINK=\"#eeeeee\" ALINK=\"#eeeeee\" ><font size=\"2\">";
if (($MODE>3)||($MODE<0)) $MODE=0;
if (($DM<1)||($DM>12)) $DM=date("m");
if (($DD<1)||($DD>31)) $DD=date("d");
//echo "$DM $DD ";
$QUERY="select txt,txt1 from daily where sm=$DM and sd=$DD ";
$db_conn=db_connect("host=localhost dbname=$DBNAME");
$result=db_exec($db_conn,$QUERY);
if (!$result){
                        echo "Ʈwd߿~AO $QUERY !";
                        exit;
 }
 $numrow=db_NumRows($result);
 if ($numrow!=1)
 {
                        echo "ƵƬO $numrow ~Id߱O $QUERY !";
                        exit;
 }
 $ARAW=db_fetch_row($result,0); //Ū̫@O
 if (strlen($ARAW[0])==0)
 {
               echo "$DM  $DD 骺Ʃ|J !";
		exit;
 }
 echo "$MD[$MODE] ";
 $ARAW[1]=trim($ARAW[1]);
 $pret=0;
 if ((strlen($ARAW[1])>0)&&($RD>0))
 {
     $spec=ref($ARAW[1],"",0,$db_conn,0);
     echo "ŪgG$spec<br>";
 	$pret=1;
 }
 if ($RD<2)
 {
   $spec=ref($ARAW[0],"",0,$db_conn,1);
   if ($pret) echo "gyG$spec";
   else echo "$spec";
 }
?>

==> cobs-0.9.tgz: cobs-0.9/new/sb.php <==
<meta http-equiv="Content-Type" CONTENT="text/html; charset=big5">
<?php
require("config.php");
require("dbconfig.php");
require("subref.php");
$MD[0]="<font size=\"2\">";
/*****************************************
$RD=0 only gy
$RD=1 gy and Ūg
$RD=2 only Ūg
*****************************************/
/**** bible.fhl.net ******/
$MD[1]="<BODY bgcolor=\"#707070\" TEXT=\"#ffffff\" LINK=\"#ffff44\" VLINK=\"#ffff44\" ALINK=\"#ffff44\" ><font size=\"2\">";
/****** a2z.fhl.net *******/
$MD[2]="<BODY bgcolor=\"#aa0000\" TEXT=\"#ffff44\" LINK=\"#eeeeee\" VLINK=\"#eeeeee\" ALINK=\"#eeeeee\" ><font size=\"1\">";
/****** http://www.biblesociety-tw.org/ *******/
$MD[3]="<BODY bgcolor=\"#808040\" TEXT=\"#ffffff\" LINK=\"#eeeeee\" VLINK=\"#eeeeee\" ALINK=\"#eeeeee\" ><font size=\"2\">";
if (($MODE>3)||($MODE<0)) $MODE=0;
if (($DM<1)||($DM>12)) $DM=date("m");
if (($DD<1)||($DD>31)) $DD=date("d");
//echo "$DM $DD ";
$QUERY="select txt,txt1 from daily where sm=$DM and sd=$DD ";
$db_conn=db_connect("host=localhost dbname=$DBNAME");
$result=db_exec($db_conn,$QUERY);
if (!$result){
                        echo "Ʈwd߿~AO $QUERY !";
                        exit;
 }
 $numrow=db_NumRows($result);
 if ($numrow!=1)
 {
                        echo "ƵƬO $numrow ~Id߱O $QUERY !";
                        exit;
 }
 $ARAW=db_fetch_row($result,0); //Ū̫@O
 if (strlen($ARAW[0])==0)
 {
               echo "$DM  $DD 骺Ʃ|J !";
		exit;
 }
 echo "$MD[$MODE] ";
 $ARAW[1]=trim($ARAW[1]);
 $pret=0;
 if ((strlen($ARAW[1])>0)&&($RD>0))
 {
     $spec=ref($ARAW[1],"",0,$db_conn,0);
     echo "ŪgG$spec<br>";
 	$pret=1;
 }
 if ($RD<2)
 {
   $spec=ref($ARAW[0],"",0,$db_conn,1);
   if ($pret) echo "gyG$spec";
   else echo "$spec";
 }
?>
